@@ -114,7 +114,7 @@ def scan(f: Callable[[Carry, X], Tuple[Carry, Y]],
       xs_slice = [x[i] for x in xs_flat]
       carry, y = f(carry, jax.tree_util.tree_unflatten(xs_tree, xs_slice))
       ys.append(y)
-    stacked_y = jax.tree_util.tree_map(lambda *y: onp.vstack(y),
+    stacked_y = jax.tree_util.tree_map(lambda *y: onp.stack(y),
                                        *maybe_reversed(ys))
     return carry, stacked_y
 
@@ -131,15 +131,15 @@ def while_loop(cond_fun: Callable[[X], Any], body_fun: Callable[[X], X],
     return val
 
 
-def fori_loop(lower: int, upper: int, body_fun: Callable[[X], X],
+def fori_loop(lower: int, upper: int, body_fun: Callable[[int, X], X],
               init_val: X) -> X:
   """Call body_fun over range from lower to upper, starting with init_val."""
   if _in_jit():
     return jax.lax.fori_loop(lower, upper, body_fun, init_val)
   else:
     val = init_val
-    for _ in range(lower, upper):
-      val = body_fun(val)
+    for i in range(lower, upper):
+      val = body_fun(i, val)
     return val
 
 
@@ -475,12 +475,13 @@ def segment_sum(data: ndarray,
 
 
 def top_k(operand: ndarray, k: int) -> ndarray:
-  """Returns top k values and their indices along the last axis of operand."""
+  """Returns the ordered top k values and their indices along the last axis of operand."""
   if _which_np(operand) is jnp:
     return jax.lax.top_k(operand, k)
   else:
-    ind = onp.argpartition(operand, -k)[-k:]
-    return operand[ind], ind
+    top_ind = onp.argpartition(operand, -k)[-k:]
+    sorted_ind = top_ind[onp.argsort(-operand[top_ind])]
+    return operand[sorted_ind], sorted_ind
 
 
 def stack(x: List[ndarray], axis=0) -> ndarray:
