@@ -379,6 +379,59 @@ class MeshTest(absltest.TestCase):
     self.assertAlmostEqual(qp.pos[0, 2], 0.38, 2)
 
 
+class CapsuleClippedPlaneTest(absltest.TestCase):
+  """Tests the capsule-clippedPlane collision function."""
+  _CONFIG = """
+    dt: 2 substeps: 1000 friction: 0.6
+    gravity { z: -9.8 }
+    bodies {
+      name: "Sphere1" mass: 1
+      colliders { sphere { radius: 0.5 } }
+      inertia { x: 1 y: 1 z: 1 }
+    }
+    bodies {
+      name: "Sphere2" mass: 1
+      colliders { sphere { radius: 0.5 } }
+      inertia { x: 1 y: 1 z: 1 }
+    }
+    bodies {
+      name: "Sphere3" mass: 1
+      colliders { sphere { radius: 0.5 } }
+      inertia { x: 1 y: 1 z: 1 }
+    }
+    bodies {
+      name: "ClippedPlane" mass: 1
+      colliders {
+        clipped_plane { halfsize_x: 3 halfsize_y: 1 }
+        position { z: 2 }
+      }
+      frozen { all: true }
+    }
+    bodies { name: "Ground" frozen: { all: true } colliders { plane {}}}
+    defaults {
+      qps { name: "Sphere1" pos { z: 3 } }
+      qps { name: "Sphere2" pos { z: 3 x: -4 } }
+      qps { name: "Sphere3" pos { z: 3 y: -2 } }
+      qps { name: "ClippedPlane" pos { x: 0 } }
+    }
+    dynamics_mode: "legacy_spring"
+  """
+
+  def test_collision(self):
+    """Tests collisions between spheres and a clipped plane."""
+    config = text_format.Parse(CapsuleClippedPlaneTest._CONFIG, brax.Config())
+    sys = brax.System(config)
+
+    qp = sys.default_qp()
+    step_fn = jax.jit(sys.step)
+    qp, _ = step_fn(qp, jp.array([]))
+    # sphere1 is on the clipped plane and sphere2/sphere3 are on the ground
+    # plane
+    self.assertAlmostEqual(qp.pos[0, 2], 2.5, 2)
+    self.assertAlmostEqual(qp.pos[1, 2], 0.5, 2)
+    self.assertAlmostEqual(qp.pos[2, 2], 0.5, 2)
+
+
 class JointTest(parameterized.TestCase):
 
   _CONFIG = """
